from setuptools import setup

setup(
    name="datasetdl",
    version="0.1.1",
    author="Stephen Grider",
    author_email="ste.grider@gmail.com",
    description="Download various datasets as json and csv files",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/StephenGrider/datasetdl",
    license="MIT",
    include_package_data=True
)
